package org.eclipse.gef.asindesigner;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.gef.asindesigner.model.AsinConnectionFactory;
import org.eclipse.gef.asindesigner.model.AsinLabel;
import org.eclipse.gef.asindesigner.model.LambdaAlternative;
import org.eclipse.gef.asindesigner.model.LeftSide;
import org.eclipse.gef.asindesigner.model.NTerminal;
import org.eclipse.gef.asindesigner.model.Terminal;
import org.eclipse.gef.palette.CombinedTemplateCreationEntry;
import org.eclipse.gef.palette.ConnectionCreationToolEntry;
import org.eclipse.gef.palette.PaletteContainer;
import org.eclipse.gef.palette.PaletteDrawer;
import org.eclipse.gef.palette.PaletteEntry;
import org.eclipse.gef.palette.PaletteGroup;
import org.eclipse.gef.palette.PaletteRoot;
import org.eclipse.gef.palette.PaletteSeparator;
import org.eclipse.gef.palette.SelectionToolEntry;
import org.eclipse.gef.palette.ToolEntry;
import org.eclipse.gef.requests.SimpleFactory;
import org.eclipse.jface.resource.ImageDescriptor;

public class AsinPlugin extends org.eclipse.ui.plugin.AbstractUIPlugin {

	private static AsinPlugin singleton;

	public AsinPlugin(IPluginDescriptor desc) {
		super(desc);
		if (singleton == null) {
			singleton = this;
		}
	}

	public static AsinPlugin getDefault() {
		return singleton;
	}

	static private List createCategories(PaletteRoot root) {
		List categories = new ArrayList();

		categories.add(createControlGroup(root));
		categories.add(createComponentsDrawer());

		return categories;
	}

	static private PaletteContainer createComponentsDrawer() {

		PaletteDrawer drawer = new PaletteDrawer(
			AsinMessages.AsinPlugin_Category_Components_Label,
			ImageDescriptor.createFromFile(
					NTerminal.class,
					"icons/comp.gif")); //$NON-NLS-1$

		List entries = new ArrayList();
		CombinedTemplateCreationEntry combined;

		combined = new CombinedTemplateCreationEntry(
			//AsinMessages.LogicPlugin_Tool_CreationTool_Circuit3_Label,
		"Left Side",
		AsinMessages.AsinPlugin_Tool_CreationTool_LeftSide_Description,
		TemplateConstants.LeftSide,
		new SimpleFactory(LeftSide.class),
		ImageDescriptor.createFromFile(LeftSide.class, "icons/leftside16.gif"), //$NON-NLS-1$
		ImageDescriptor.createFromFile(LeftSide.class, "icons/circuit224.gif") //$NON-NLS-1$
	);
		entries.add(combined);

		combined = new CombinedTemplateCreationEntry(
			//AsinMessages.LogicPlugin_Tool_CreationTool_Circuit_Label,
		"N Terminal",
		AsinMessages.AsinPlugin_Tool_CreationTool_NTerminal_Description, 
		TemplateConstants.NTerminal,
		new SimpleFactory(NTerminal.class),
		ImageDescriptor.createFromFile(NTerminal.class, "icons/nterminal16.gif"), //$NON-NLS-1$
		ImageDescriptor.createFromFile(NTerminal.class, "icons/circuit24.gif") //$NON-NLS-1$
	);
		entries.add(combined);

		combined = new CombinedTemplateCreationEntry(
			//AsinMessages.LogicPlugin_Tool_CreationTool_Circuit2_Label,
		"Terminal",
		AsinMessages.AsinPlugin_Tool_CreationTool_Terminal_Description,
		TemplateConstants.Terminal,
		new SimpleFactory(Terminal.class),
	    ImageDescriptor.createFromFile(Terminal.class, "icons/terminal16.gif"), //$NON-NLS-1$
		ImageDescriptor.createFromFile(Terminal.class, "icons/circuit224.gif") //$NON-NLS-1$
	);
		entries.add(combined);

		combined = new CombinedTemplateCreationEntry(
			//AsinMessages.LogicPlugin_Tool_CreationTool_Circuit2_Label,
			"Lambda-Alternative",
		 	AsinMessages.AsinPlugin_Tool_CreationTool_LambdaAlternative_Description,
			TemplateConstants.LambdaAlternative,
			new SimpleFactory(LambdaAlternative.class),
		    ImageDescriptor.createFromFile(LambdaAlternative.class, "icons/lambdaAlt16.gif"), //$NON-NLS-1$
		    ImageDescriptor.createFromFile(LambdaAlternative.class, "icons/lambdaAlt24.gif") //$NON-NLS-1$
	);
		entries.add(combined);
		

		entries.add(new PaletteSeparator());

		combined = new CombinedTemplateCreationEntry(AsinMessages.AsinPlugin_Tool_CreationTool_Label_Label, 
			AsinMessages.AsinPlugin_Tool_CreationTool_Label_Description,
			TemplateConstants.Label,
		 	new SimpleFactory(AsinLabel.class),
		 	ImageDescriptor.createFromFile(AsinLabel.class, "icons/label16.gif"), //$NON-NLS-1$
			ImageDescriptor.createFromFile(AsinLabel.class, "icons/label24.gif") //$NON-NLS-1$
	);
		entries.add(combined);

		drawer.addAll(entries);
		return drawer;
	}

	static private PaletteContainer createControlGroup(PaletteRoot root) {
		PaletteGroup controlGroup =
			new PaletteGroup(
				AsinMessages.AsinPlugin_Category_ControlGroup_Label);

		List entries = new ArrayList();

		ToolEntry tool = new SelectionToolEntry();
		entries.add(tool);
		root.setDefaultEntry(tool);

		//tool = new MarqueeToolEntry();
		//entries.add(tool);

		PaletteSeparator sep = new PaletteSeparator("org.eclipse.gef.examples.logicdesigner.logicplugin.sep2"); //$NON-NLS-1$
		sep.setUserModificationPermission(
			PaletteEntry.PERMISSION_NO_MODIFICATION);
		entries.add(sep); //$NON-NLS-1$
	
			tool = new ConnectionCreationToolEntry(
					AsinMessages.AsinPlugin_Tool_ConnectionCreationTool_Sucessor_Label,
					AsinMessages.AsinPlugin_Tool_ConnectionCreationTool_Sucessor_Description,
					new AsinConnectionFactory("Wire"),
					ImageDescriptor.createFromFile(NTerminal.class, "icons/connection16.gif"), //$NON-NLS-1$
						ImageDescriptor.createFromFile(NTerminal.class, "icons/connection24.gif") //$NON-NLS-1$
	);
		entries.add(tool);

			tool = new ConnectionCreationToolEntry(AsinMessages.AsinPlugin_Tool_ConnectionCreationTool_Alternative_Label, AsinMessages.AsinPlugin_Tool_ConnectionCreationTool_Alternative_Description, new AsinConnectionFactory("Wire2"), ImageDescriptor.createFromFile(NTerminal.class, "icons/connection16.gif"), //$NON-NLS-1$
		ImageDescriptor.createFromFile(NTerminal.class, "icons/connection24.gif") //$NON-NLS-1$
	);
		entries.add(tool);
		controlGroup.addAll(entries);
		return controlGroup;
	}

	static PaletteRoot createPalette() {
		PaletteRoot logicPalette = new PaletteRoot();
		logicPalette.addAll(createCategories(logicPalette));
		return logicPalette;
	}

}