package org.eclipse.gef.asindesigner;

import org.eclipse.gef.EditPartViewer;
import org.eclipse.gef.asindesigner.actions.GenerateGramaticAction;
import org.eclipse.gef.asindesigner.actions.ParseAction;
import org.eclipse.gef.ui.actions.ActionRegistry;
import org.eclipse.gef.ui.actions.GEFActionConstants;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.ui.IWorkbenchActionConstants;
public class AsincContextMenuProvider
	extends org.eclipse.gef.ContextMenuProvider {

	private ActionRegistry actionRegistry;

	public AsincContextMenuProvider(
		EditPartViewer viewer,
		ActionRegistry registry) {
		super(viewer);
		setActionRegistry(registry);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.gef.ContextMenuProvider#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
	 *
	 *Para criar o menu quando o boto do mouse  pressionado...
	 *
	 */

	public void buildContextMenu(IMenuManager manager) {
		GEFActionConstants.addStandardActionGroups(manager);

		IAction action;

		action = getActionRegistry().getAction(GEFActionConstants.UNDO);
		manager.appendToGroup(GEFActionConstants.GROUP_UNDO, action);

		action = getActionRegistry().getAction(GEFActionConstants.REDO);
		manager.appendToGroup(GEFActionConstants.GROUP_UNDO, action);

		action = getActionRegistry().getAction(IWorkbenchActionConstants.PASTE);
		if (action.isEnabled())
			manager.appendToGroup(GEFActionConstants.GROUP_EDIT, action);

		action =
			getActionRegistry().getAction(IWorkbenchActionConstants.DELETE);
		if (action.isEnabled())
			manager.appendToGroup(GEFActionConstants.GROUP_EDIT, action);

		action = getActionRegistry().getAction(GEFActionConstants.DIRECT_EDIT);
		if (action.isEnabled())
			manager.appendToGroup(GEFActionConstants.GROUP_EDIT, action);

		action =
			getActionRegistry().getAction(GenerateGramaticAction.GENERATE);
		if (action.isEnabled())
			manager.appendToGroup(GEFActionConstants.GROUP_REST, action);
		action = getActionRegistry().getAction(ParseAction.PARSE);
		if (action.isEnabled())
			manager.appendToGroup(GEFActionConstants.GROUP_REST, action);

		// Alignment Actions
		MenuManager submenu =
			new MenuManager(
				AsinMessages.AlignmentAction_AlignSubmenu_ActionLabelText);

		action = getActionRegistry().getAction(GEFActionConstants.ALIGN_LEFT);
		if (action.isEnabled())
			submenu.add(action);

		action = getActionRegistry().getAction(GEFActionConstants.ALIGN_CENTER);
		if (action.isEnabled())
			submenu.add(action);

		action = getActionRegistry().getAction(GEFActionConstants.ALIGN_RIGHT);
		if (action.isEnabled())
			submenu.add(action);

		action = getActionRegistry().getAction(GEFActionConstants.ALIGN_TOP);
		if (action.isEnabled())
			submenu.add(action);

		action = getActionRegistry().getAction(GEFActionConstants.ALIGN_MIDDLE);
		if (action.isEnabled())
			submenu.add(action);

		action = getActionRegistry().getAction(GEFActionConstants.ALIGN_BOTTOM);
		if (action.isEnabled())
			submenu.add(action);

		if (!submenu.isEmpty())
			manager.appendToGroup(GEFActionConstants.GROUP_REST, submenu);

		action = getActionRegistry().getAction(IWorkbenchActionConstants.SAVE);
		manager.appendToGroup(GEFActionConstants.GROUP_SAVE, action);

	}

	private ActionRegistry getActionRegistry() {
		return actionRegistry;
	}

	private void setActionRegistry(ActionRegistry registry) {
		actionRegistry = registry;
	}

}