package org.eclipse.gef.asindesigner.edit;

import java.beans.PropertyChangeEvent;

import org.eclipse.draw2d.Border;
import org.eclipse.draw2d.CompoundBorder;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.Label;
import org.eclipse.draw2d.LineBorder;
import org.eclipse.draw2d.MarginBorder;
import org.eclipse.gef.AccessibleEditPart;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.Request;
import org.eclipse.gef.RequestConstants;
import org.eclipse.gef.asindesigner.AsinMessages;
import org.eclipse.gef.asindesigner.model.AsinLabel;
import org.eclipse.gef.tools.DirectEditManager;
import org.eclipse.jface.viewers.TextCellEditor;
import org.eclipse.swt.accessibility.AccessibleControlEvent;
import org.eclipse.swt.accessibility.AccessibleEvent;

public class AsinLabelEditPart
	extends AsinEditPart
{
	
protected AccessibleEditPart createAccessible() {
	return new AccessibleGraphicalEditPart(){
		public void getValue(AccessibleControlEvent e) {
			e.result = getLogicLabel().getLabelContents();
		}

		public void getName(AccessibleEvent e) {
			e.result = AsinMessages.AsinPlugin_Tool_CreationTool_AsinLabel;
		}
	};
}

private DirectEditManager manager;

private static Border BORDER = new CompoundBorder(
	new LineBorder(),
	new MarginBorder(2)
);

protected void createEditPolicies(){
	super.createEditPolicies();
	installEditPolicy(EditPolicy.GRAPHICAL_NODE_ROLE, null);		
	installEditPolicy(EditPolicy.DIRECT_EDIT_ROLE, new LabelDirectEditPolicy());
	installEditPolicy(EditPolicy.COMPONENT_ROLE,new AsinLabelEditPolicy()); 
}

protected IFigure createFigure() {
	Label label = new Label();
	//label.setBorder(BORDER);
	return label;
}

private AsinLabel getLogicLabel(){
	return (AsinLabel)getModel();
}

private void performDirectEdit(){
	if(manager == null)
		manager = new AsinLabelEditManager(this, 
			TextCellEditor.class, new LabelCellEditorLocator((Label)getFigure()));
	manager.show();
}

public void performRequest(Request request){
	if (request.getType() == RequestConstants.REQ_DIRECT_EDIT)
		performDirectEdit();
}

public void propertyChange(PropertyChangeEvent evt){
	if (evt.getPropertyName().equalsIgnoreCase("labelContents"))//$NON-NLS-1$
		refreshVisuals();
	else
		super.propertyChange(evt);
}

protected void refreshVisuals() {
	((Label)getFigure()).setText(getLogicLabel().getLabelContents());
	super.refreshVisuals();
}

}