package org.eclipse.gef.asindesigner.edit;

import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.Request;
import org.eclipse.gef.asindesigner.AsinMessages;
import org.eclipse.gef.asindesigner.model.AsinDiagram;
import org.eclipse.gef.asindesigner.model.AsinSubpart;
import org.eclipse.gef.asindesigner.model.commands.AddCommand;
import org.eclipse.gef.asindesigner.model.commands.CreateCommand;
import org.eclipse.gef.asindesigner.model.commands.SetConstraintCommand;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.editpolicies.NonResizableEditPolicy;
import org.eclipse.gef.requests.CreateRequest;

public class AsinXYLayoutEditPolicy
	extends org.eclipse.gef.editpolicies.XYLayoutEditPolicy
{

protected Command createAddCommand(EditPart childEditPart, Object constraint) {

	AsinSubpart part = (AsinSubpart)childEditPart.getModel();
	Rectangle rect = (Rectangle)constraint;

	AddCommand add = new AddCommand();
	add.setParent((AsinDiagram)getHost().getModel());
	add.setChild(part);
	add.setLabel(AsinMessages.AsinXYLayoutEditPolicy_AddCommandLabelText);
	add.setDebugLabel("LogicXYEP add subpart");//$NON-NLS-1$

	SetConstraintCommand setConstraint = new SetConstraintCommand();

	setConstraint.setLocation(rect);
	setConstraint.setPart(part);
	setConstraint.setLabel(AsinMessages.AsinXYLayoutEditPolicy_AddCommandLabelText);
	setConstraint.setDebugLabel("LogicXYEP setConstraint");//$NON-NLS-1$
	return add.chain(setConstraint);
}

protected Command createChangeConstraintCommand(EditPart child, Object constraint) {
	SetConstraintCommand locationCommand = new SetConstraintCommand();
	locationCommand.setPart((AsinSubpart)child.getModel());
	locationCommand.setLocation((Rectangle)constraint);
	return locationCommand;
}

protected EditPolicy createChildEditPolicy(EditPart child) {
	if (child instanceof OutputEditPart || 
	    child instanceof AsinLabelEditPart) {
		return new NonResizableEditPolicy();
	}
	return super.createChildEditPolicy(child);
}

protected Command getCreateCommand(CreateRequest request) {
	CreateCommand create = new CreateCommand();
	create.setParent((AsinDiagram)getHost().getModel());
	create.setChild((AsinSubpart)request.getNewObject());
	Rectangle constraint = (Rectangle)getConstraintFor(request);
	create.setLocation(constraint);
	create.setLabel(AsinMessages.AsinXYLayoutEditPolicy_CreateCommandLabelText);
	return create;
}

protected Command getDeleteDependantCommand(Request request) {
	return null;
}

protected Command getOrphanChildrenCommand(Request request) {
	return null;
}

}