package org.eclipse.gef.asindesigner.edit;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPartFactory;
import org.eclipse.gef.asindesigner.model.AsinDiagram;
import org.eclipse.gef.asindesigner.model.AsinFlowContainer;
import org.eclipse.gef.asindesigner.model.AsinLabel;
import org.eclipse.gef.asindesigner.model.EndNode;
import org.eclipse.gef.asindesigner.model.LambdaAlternative;
import org.eclipse.gef.asindesigner.model.LeftSide;
import org.eclipse.gef.asindesigner.model.NTerminal;
import org.eclipse.gef.asindesigner.model.SimpleOutput;
import org.eclipse.gef.asindesigner.model.Terminal;
import org.eclipse.gef.asindesigner.model.Wire;

public class GraphicalPartFactory implements EditPartFactory {

	public EditPart createEditPart(EditPart context, Object model) {
		EditPart child = null;

		if (model instanceof AsinFlowContainer)
			child = new AsinFlowContainerEditPart();
		else if (model instanceof Wire)
			child = new WireEditPart();		
		else if (model instanceof AsinLabel)
			child = new AsinLabelEditPart();
		else if (model instanceof NTerminal)
			child = new NTerminalEditPart();
		else if (model instanceof Terminal)
			child = new TerminalEditPart();
		else if (model instanceof EndNode)
				child = new GateEditPart();
		else if (model instanceof LambdaAlternative)
				child = new GateEditPart();	
		else if (model instanceof LeftSide)
			child = new LeftSideEditPart();		
		else if (model instanceof SimpleOutput)
			child = new OutputEditPart();
		//Note that subclasses of AsinDiagram have already been matched above, like NTerminal
		else if (model instanceof AsinDiagram)
			child = new AsinDiagramEditPart();
		child.setModel(model);
		return child;
	}

}
