package org.eclipse.gef.asindesigner.figures;

import org.eclipse.draw2d.ColorConstants;
import org.eclipse.draw2d.ConnectionAnchor;
import org.eclipse.draw2d.FreeformLayer;
import org.eclipse.draw2d.FreeformLayout;
import org.eclipse.draw2d.FreeformViewport;
import org.eclipse.draw2d.Graphics;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.ScrollPane;
import org.eclipse.draw2d.StackLayout;
import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.draw2d.geometry.Insets;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.gef.asindesigner.model.Terminal;
import org.eclipse.gef.handles.HandleBounds;

public class NTerminalFigure
	extends NodeFigure
	implements HandleBounds
{
	private IFigure pane;

		public NTerminalFigure() {
			setBorder(new NTerminalBorder());
			ScrollPane scrollpane = new ScrollPane();
			pane = new FreeformLayer();
			pane.setLayoutManager(new FreeformLayout());
			setLayoutManager(new StackLayout());
			add(scrollpane);
			scrollpane.setViewport(new FreeformViewport());
			scrollpane.setContents(pane);

			createConnectionAnchors();
			setBackgroundColor(ColorConstants.listBackground);
			setOpaque(true);
		}

		protected void createConnectionAnchors() {
			FixedConnectionAnchor2 in, out;
			for (int i = 0; i < 4; i++) {
				in = new FixedConnectionAnchor2(this);
				out = new FixedConnectionAnchor2(this);
				if (i == 0) {
					in.left = true;
				}
				if (i == 1) {
					in.top = true;
				}
				if (i == 2) {
					in.right = true;
				}
				if (i == 3) {
					in.botton = true;
				}
				setOutputConnectionAnchor(i, out);
				setInputConnectionAnchor(i, in);
				outputConnectionAnchors.addElement(out);
				inputConnectionAnchors.addElement(in);
			}
			//System.out.println("Feita a chamada a createConnectionAnchors()");
		}

		public IFigure getContentsPane() {
			return pane;
		}

		protected FixedConnectionAnchor2 getInputConnectionAnchor(int i) {
			return (FixedConnectionAnchor2) connectionAnchors.get(
				Terminal.TERMINALS_IN[i]);
		}

		/**
		 * @see org.eclipse.gef.handles.HandleBounds#getHandleBounds()
		 */
		public Rectangle getHandleBounds() {
			return getBounds().getCropped(new Insets(2, 0, 2, 0));
		}

		protected FixedConnectionAnchor2 getOutputConnectionAnchor(int i) {
			return (FixedConnectionAnchor2) connectionAnchors.get(
				Terminal.TERMINALS_OUT[i]);
		}

		public Dimension getPreferredSize(int w, int h) {
			Dimension prefSize = super.getPreferredSize(w, h);
			Dimension defaultSize = new Dimension(100,100);
			prefSize.union(defaultSize);
			return prefSize;
		}

		protected void layoutConnectionAnchors() {
			getOutputConnectionAnchor(0).offsetH = 0;
			getOutputConnectionAnchor(0).offsetV = this.getSize().height / 2;
		
			getInputConnectionAnchor(0).offsetH = 0;
			getInputConnectionAnchor(0).offsetV = (this.getSize().height / 2);
		
			getOutputConnectionAnchor(1).offsetH = this.getSize().width / 2;
			getOutputConnectionAnchor(1).offsetV = 0;
		
			getInputConnectionAnchor(1).offsetH = (this.getSize().width / 2);
			getInputConnectionAnchor(1).offsetV = 0;

			getOutputConnectionAnchor(2).offsetH = this.getSize().width;
			getOutputConnectionAnchor(2).offsetV = this.getSize().height / 2;
		
			getInputConnectionAnchor(2).offsetH = this.getSize().width;
			getInputConnectionAnchor(2).offsetV =this.getBounds().height / 2;

			getOutputConnectionAnchor(3).offsetH = this.getSize().width / 2;
			getOutputConnectionAnchor(3).offsetV = this.getSize().height;
		
			getInputConnectionAnchor(3).offsetH = this.getSize().width /2;
			getInputConnectionAnchor(3).offsetV = this.getSize().height;
		
			//System.out.println("Feita a chamada a layoutConnectionAnchors()");

		}

		/**
		 * @see org.eclipse.draw2d.Figure#paintFigure(Graphics)
		 */
		protected void paintFigure(Graphics graphics) {
			Rectangle rect = getBounds().getCopy();
			rect.crop(new Insets(2, 0, 2, 0));
			graphics.fillRectangle(rect);
		}

		public void setInputConnectionAnchor(int i, ConnectionAnchor c) {
			connectionAnchors.put(Terminal.TERMINALS_IN[i], c);
		}

		public void setOutputConnectionAnchor(int i, ConnectionAnchor c) {
			connectionAnchors.put(Terminal.TERMINALS_OUT[i], c);
		}

		public String toString() {
			return "CircuitBoardFigure"; //$NON-NLS-1$
		}

		public void validate() {
			if (isValid())
				return;
			layoutConnectionAnchors();
			super.validate();
		}

		protected boolean useLocalCoordinates() {
			return true;
		}

}