package org.eclipse.gef.asindesigner.model;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.*;

import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.IPropertySource;

abstract public class AsinElement
	implements IPropertySource, Cloneable, Serializable
{

public static final String
	CHILDREN = "Children", 	//$NON-NLS-1$
	INPUTS = "inputs",	//$NON-NLS-1$
	OUTPUTS = "outputs";	//$NON-NLS-1$

/* Declara um objeto PropertyChangeSupport (listener), que enviar uma mensagem 
 * aos listeners assim que nele, algo for alterado
 */
 
 /* como listeners est como transiente, ele no ser serializado como parte do objeto*/
transient protected PropertyChangeSupport listeners = new PropertyChangeSupport(this);

static final long serialVersionUID = 1;

/* Adiciona o objeto l, que implementa PropertyChangeListener em listener*/
public void addPropertyChangeListener(PropertyChangeListener l){
	listeners.addPropertyChangeListener(l);
}

protected void firePropertyChange(String prop, Object old, Object newValue){
	listeners.firePropertyChange(prop, old, newValue);
}

protected void fireStructureChange(String prop, Object child){
	listeners.firePropertyChange(prop, null, child);
}

public void removePropertyChangeListener(PropertyChangeListener l){
	listeners.removePropertyChangeListener(l);
}


/* ********************Mtodos da interface IPropertySource*********************** */
public Object getEditableValue(){
	return this;
}

public IPropertyDescriptor[] getPropertyDescriptors(){
	return new IPropertyDescriptor[0];
}

public Object getPropertyValue(Object propName){
	return null;
}

final Object getPropertyValue(String propName){
	return null;
}

public boolean isPropertySet(Object propName){
	return isPropertySet((String)propName);
}
final boolean isPropertySet(String propName) {
	return true;
}

public void resetPropertyValue(Object propName) {
}

final void resetPropertyValue(String propName) {
}

public void setPropertyValue(Object propName, Object val) {
}
final void setPropertyValue(String propName, Object val) {
}
/* ******************************************************************** */

/* Metodo da interface serializible*/
private void readObject(ObjectInputStream in)throws IOException, ClassNotFoundException {
	in.defaultReadObject();
	listeners = new PropertyChangeSupport(this);
}


public void update(){
}

}
