package org.eclipse.gef.asindesigner.model.commands;

import org.eclipse.gef.asindesigner.AsinMessages;
import org.eclipse.gef.asindesigner.model.AsinSubpart;
import org.eclipse.gef.asindesigner.model.Wire;
import org.eclipse.gef.commands.Command;

public class ConnectionCommand
	extends Command
{

protected AsinSubpart oldSource;
protected String oldSourceTerminal;
protected AsinSubpart oldTarget;
protected String oldTargetTerminal;
protected AsinSubpart source;
protected String sourceTerminal;
protected AsinSubpart target; 
protected String targetTerminal; 
protected Wire wire;

public ConnectionCommand() {
	super(AsinMessages.ConnectionCommand_Label);
}

public boolean canExecute(){
	return true;
}

public void execute() {
	if (source != null){
		wire.detachSource();
		wire.setSource(source);
		wire.setSourceTerminal(sourceTerminal);
		wire.attachSource();
	}
	if (target != null) {
		wire.detachTarget();
		wire.setTarget(target);
		wire.setTargetTerminal(targetTerminal);
		wire.attachTarget();
	}
	if (source == null && target == null){
		wire.detachSource();
		wire.detachTarget();
		wire.setTarget(null);
		wire.setSource(null);
	}
}

public String getLabel() {
	return AsinMessages.ConnectionCommand_Description;
}

public AsinSubpart getSource() {
	return source;
}

public java.lang.String getSourceTerminal() {
	return sourceTerminal;
}

public AsinSubpart getTarget() {
	return target;
}

public String getTargetTerminal() {
	return targetTerminal;
}

public Wire getWire() {
	return wire;
}

public void redo() { 
	execute(); 
}

public void setSource(AsinSubpart newSource) {
	source = newSource;
}

public void setSourceTerminal(String newSourceTerminal) {
	sourceTerminal = newSourceTerminal;
}

public void setTarget(AsinSubpart newTarget) {
	target = newTarget;
}

public void setTargetTerminal(String newTargetTerminal) {
	targetTerminal = newTargetTerminal;
}

public void setWire(Wire w) {
	wire = w;
	oldSource = w.getSource();
	oldTarget = w.getTarget();
	oldSourceTerminal = w.getSourceTerminal();
	oldTargetTerminal = w.getTargetTerminal();	
}

public void undo() {
	source = wire.getSource();
	target = wire.getTarget();
	sourceTerminal = wire.getSourceTerminal();
	targetTerminal = wire.getTargetTerminal();

	wire.detachSource();
	wire.detachTarget();

	wire.setSource(oldSource);
	wire.setTarget(oldTarget);
	wire.setSourceTerminal(oldSourceTerminal);
	wire.setTargetTerminal(oldTargetTerminal);

	wire.attachSource();
	wire.attachTarget();
}

}
