package org.eclipse.gef.asindesigner.model.commands;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.gef.asindesigner.AsinMessages;
import org.eclipse.gef.asindesigner.model.AsinDiagram;
import org.eclipse.gef.asindesigner.model.AsinSubpart;
import org.eclipse.gef.asindesigner.model.Wire;
import org.eclipse.gef.commands.Command;

public class DeleteCommand
	extends Command
{

private AsinSubpart child;
private AsinDiagram parent;
private int index = -1;
private List sourceConnections = new ArrayList();
private List targetConnections = new ArrayList();

public DeleteCommand() {
	super(AsinMessages.DeleteCommand_Label);
}

private void deleteConnections(AsinSubpart part) {
	if (part instanceof AsinDiagram) {
		List children = ((AsinDiagram)part).getChildren();
		for (int i = 0; i < children.size(); i++)
			deleteConnections((AsinSubpart)children.get(i));
	}
	sourceConnections.addAll(part.getSourceConnections());
	for (int i = 0; i < sourceConnections.size(); i++) {
		Wire wire = (Wire)sourceConnections.get(i);
		wire.detachSource();
		wire.detachTarget();
	}
	targetConnections.addAll(part.getTargetConnections());
	for (int i = 0; i < targetConnections.size(); i++) {
		Wire wire = (Wire)targetConnections.get(i);
		wire.detachSource();
		wire.detachTarget();
	}
}

public void execute() {
	primExecute();
}

protected void primExecute() {
	deleteConnections(child);
	index = parent.getChildren().indexOf(child);
	parent.removeChild(child);
}

public void redo() {
	primExecute();
}

private void restoreConnections() {
	for (int i = 0; i < sourceConnections.size(); i++) {
		Wire wire = (Wire)sourceConnections.get(i);
		wire.attachSource();
		wire.attachTarget();
	}
	sourceConnections.clear();
	for (int i = 0; i < targetConnections.size(); i++) {
		Wire wire = (Wire)targetConnections.get(i);
		wire.attachSource();
		wire.attachTarget();
	}
	targetConnections.clear();
}

public void setChild (AsinSubpart c) {
	child = c;
}

public void setParent(AsinDiagram p) {
	parent = p;
}

public void undo() {
	parent.addChild(child, index);
	restoreConnections();
}

}
