package org.eclipse.gef.asinview;

import org.eclipse.gef.asindesigner.AsinPlugin;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.part.ViewPart;

public class AsinView extends ViewPart {
	static public Text outview;

	public void createPartControl(Composite parent) {
		Text t =
			new Text(
				parent,
				SWT.READ_ONLY | SWT.WRAP | SWT.H_SCROLL | SWT.V_SCROLL);
		IToolBarManager tbm =
			this.getViewSite().getActionBars().getToolBarManager();
		createPrintSyntaxStack(tbm);
		createPrintSemanticStack(tbm);
		createPrintSemanticRoutinesOutput(tbm);
		createPrintTokens(tbm);
		createErrorRecoveryStatus(tbm);
		createClearView(tbm);
		outview = t;
	}
	public void setFocus() {
		// set focus to my widget.  For a label, this doesn't
		// make much sense, but for more complex sets of widgets
		// you would decide which one gets the focus.
	}

	static public void displayText(String str) {
		if (outview != null)
			outview.append(str);
	}
	static public void printSyntaxStack(String str) {
		PrintVariables pVar = SingletonManager.getVariables();
		if (pVar.printSyntaxStack)
			if (outview != null)
				outview.append(str);
	}
	static public void printSemanticStack(String str) {
			PrintVariables pVar = SingletonManager.getVariables();
			if (pVar.printSemanticStack)
				if (outview != null)
					outview.append(str);
		}


	static public void semanticRoutinesOutput(String str) {
		PrintVariables pVar = SingletonManager.getVariables();
		if (pVar.printSemanticRoutinesOutput)
			if (outview != null)
				outview.append(str);
	}
	
	static public void errorRecoveryStatus(String str) {
			PrintVariables pVar = SingletonManager.getVariables();
			if (pVar.errorRecoveryStatus)
				if (outview != null)
					outview.append(str);
	}

	static public void printToken(String str) {
		PrintVariables pVar = SingletonManager.getVariables();
		if (pVar.printTokens)
			if (outview != null)
				outview.append(str);
	}

	private void createPrintSemanticRoutinesOutput(IToolBarManager tbm) {
		Action pSRoutines = new Action() {
			public void run() {
				PrintVariables pVar = SingletonManager.getVariables();
				if (!pVar.printSemanticRoutinesOutput) {
					pVar.printSemanticRoutinesOutput = true;
					this.setImageDescriptor(
						ImageDescriptor.createFromFile(
							AsinPlugin.class,
							"icons/activeSemanticOutput.gif"));

				} else {
					pVar.printSemanticRoutinesOutput = false;
					this.setImageDescriptor(
						ImageDescriptor.createFromFile(
							AsinPlugin.class,
							"icons/SemanticOutput.gif"));
				}
			}
		};
		pSRoutines.setImageDescriptor(ImageDescriptor.createFromFile(AsinPlugin.class, "icons/SemanticOutput.gif")); //$NON-NLS-1$
		pSRoutines.setToolTipText("Semantic routines output");
		tbm.add(pSRoutines);
	}
	
	private void createErrorRecoveryStatus(IToolBarManager tbm) {
			Action pERS = new Action() {
				public void run() {
					PrintVariables pVar = SingletonManager.getVariables();
					if (!pVar.errorRecoveryStatus) {
						pVar.errorRecoveryStatus = true;
						this.setImageDescriptor(
							ImageDescriptor.createFromFile(
								AsinPlugin.class,
								"icons/activeErrorRecoveryStatus.gif"));

					} else {
						pVar.errorRecoveryStatus = false;
						this.setImageDescriptor(
							ImageDescriptor.createFromFile(
								AsinPlugin.class,
								"icons/errorRecoveryStatus.gif"));
					}
				}
			};
			pERS.setImageDescriptor(ImageDescriptor.createFromFile(AsinPlugin.class, "icons/errorRecoveryStatus.gif")); //$NON-NLS-1$
			pERS.setToolTipText("Error recovery status");
			tbm.add(pERS);
		}

	private void createPrintSyntaxStack(IToolBarManager tbm) {
		Action pSStack = new Action() {
			public void run() {
				PrintVariables pVar = SingletonManager.getVariables();
				if (!pVar.printSyntaxStack) {
					pVar.printSyntaxStack = true;
					this.setImageDescriptor(
						ImageDescriptor.createFromFile(
							AsinPlugin.class,
							"icons/activeSyntaxStack.gif"));
				} else {
					pVar.printSyntaxStack = false;
					this.setImageDescriptor(
						ImageDescriptor.createFromFile(
							AsinPlugin.class,
							"icons/SyntaxStack.gif"));
				}
			}
		};
		pSStack.setImageDescriptor(ImageDescriptor.createFromFile(AsinPlugin.class, "icons/SyntaxStack.gif")); //$NON-NLS-1$
		pSStack.setToolTipText("Print the syntax stack");
		tbm.add(pSStack);
	}
	
	private void createPrintSemanticStack(IToolBarManager tbm) {
			Action pSemStack = new Action() {
				public void run() {
					PrintVariables pVar = SingletonManager.getVariables();
					if (!pVar.printSemanticStack) {
						pVar.printSemanticStack = true;
						this.setImageDescriptor(
							ImageDescriptor.createFromFile(
								AsinPlugin.class,
								"icons/activeSemanticStack.gif"));
					} else {
						pVar.printSemanticStack = false;
						this.setImageDescriptor(
							ImageDescriptor.createFromFile(
								AsinPlugin.class,
								"icons/SemanticStack.gif"));
					}
				}
			};
			pSemStack.setImageDescriptor(ImageDescriptor.createFromFile(AsinPlugin.class, "icons/SemanticStack.gif")); //$NON-NLS-1$
			pSemStack.setToolTipText("Print the semantic stack");
			tbm.add(pSemStack);
		}
	
	
	

	private void createPrintTokens(IToolBarManager tbm) {
		Action pTokens = new Action() {
			public void run() {
				PrintVariables pVar = SingletonManager.getVariables();
				if (!pVar.printTokens) {
					pVar.printTokens = true;
					this.setImageDescriptor(ImageDescriptor.createFromFile(AsinPlugin.class, "icons/activeToken.gif")); //$NON-NLS-1$
				} else {
					pVar.printTokens = false;
					this.setImageDescriptor(ImageDescriptor.createFromFile(AsinPlugin.class, "icons/token.gif")); //$NON-NLS-1$
				}
			}
		};
		pTokens.setImageDescriptor(ImageDescriptor.createFromFile(AsinPlugin.class, "icons/token.gif")); //$NON-NLS-1$
		pTokens.setToolTipText("Print the recognized tokens");
		tbm.add(pTokens);
	}

	private void createClearView(IToolBarManager tbm) {
		Action clearView = new Action() {
			public void run() {
				outview.setText("");
			}
		};
		clearView.setImageDescriptor(ImageDescriptor.createFromFile(AsinPlugin.class, "icons/clear.gif")); //$NON-NLS-1$
		clearView.setToolTipText("Clear Asin output view");
		tbm.add(clearView);
	}

}
